@@ -4,7 +4,7 @@ use 5.010;
 use strict;
 use warnings;
 use utf8;
-use open qw(:std :utf8);
+# use open qw(:std :utf8);
 
 require Exporter;
 
@@ -20,8 +20,7 @@ our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 
 our @EXPORT = qw( );
 
-our $VERSION = '0.07';
-
+our $VERSION = '0.071';
 
 ########################
 #  num2cardinal INPUT  #
@@ -1260,7 +1259,7 @@ Will print the results:
 
 =item 14.
 
-Usage for correct case endings only (without numeral written as a string):
+To get the $number that is padded with Russian numeral in parentheses:
 
   say spelled_out_number( 100_000, case=>'accusative', 'prolog'=>'за', 'epilog'=>'CNY', 'ucfirst'=>1 );
 
@@ -1338,22 +1337,22 @@ The following can be global C<%facultative_options>:
 =over 6
 
 =item 1.
-C<'n'|'nominative'> (I<Именительный падеж: есть кто? что?> is B<default>),
+C<'n'|'nominative'> (I<Именительный падеж: есть кто? что? сколько?> is B<default>),
 
 =item 2.
-C<'g'|'genitive'> (I<Родительный падеж: нет кого? чего?>),
+C<'g'|'genitive'> (I<Родительный падеж: нет кого? чего? скольких?>),
 
 =item 3.
-C<'d'|'dative'> (I<Дательный падеж: рад кому? чему?>),
+C<'d'|'dative'> (I<Дательный падеж: рад кому? чему? скольким?>),
 
 =item 4.
-C<'a'|'accusative'> (I<Винительный падеж: вижу кого? что?>),
+C<'a'|'accusative'> (I<Винительный падеж: вижу кого? что? скольких? (одуш) сколько? (неодуш)>),
 
 =item 5.
-C<'i'|'instrumental'> (I<Творительный падеж: оплачу кем? чем?>),
+C<'i'|'instrumental'> (I<Творительный падеж: оплачу кем? чем? сколькими?>),
 
 =item 6.
-C<'p'|'prepositional'> (I<Предложный падеж: думаю о ком? о чём?>).
+C<'p'|'prepositional'> (I<Предложный падеж: думаю о ком? о чём? о скольких?>).
 
 =back
 
@@ -1379,7 +1378,7 @@ If C<'prolog'> is SCALAR value (e.g. C<< 'prolog'=>'о' >>) then it is used from
 In this case, the inner prolog controls B<case of the numeral> and overrides (suppresses or affirms its authority)
 the global option C<'case'>.
 
-Now internal B<reference list of prologs> contains the following preconfigured phrase structures, i.e. the inner prolog:
+Now internal B<reference list of prologs> contains the following preconfigured phrase structures, i.e. the inner prologs:
 
 =over 6
 
@@ -1449,7 +1448,7 @@ C<благодаря> — equivalent to C<['благодаря']>.
 =item *
 for B<accusative> (I<Винительный>) and B<prepositional> cases (I<Предложный падеж>):
 
-на — equivalent to C<['на']>.
+C<на> — equivalent to C<['на']>.
 
 C<o>, C<oб>, C<oбо> — equivalent to C<['о','об=од']>.
 
@@ -1479,7 +1478,7 @@ Internal B<reference list of epilogs> contains the following preconfigured phras
 =over 6
 
 =item * C<RUB|RUR|643|810|₽|рубль|ruble> — for Russian ruble (I<Российский рубль>);
-C<rub|rur|-643|-810|byb|byr|byn|\-933|\-974|копейка|kopek> — for kopek (I<копейка>).
+C<rub|rur|-643|-810|byb|byr|byn|-933|-974|копейка|kopek> — for kopek (I<копейка>).
 
 =item * C<CNY|RMB|156|юань|yuan> — Chinese yuan;
 C<cny|rmb|-156|фынь> — for Chinese cent.
@@ -1511,7 +1510,7 @@ For example, I<год>, I<лет> (shorthand equivalent is C<$epilog = 'year'> f
                'ends'   => [['лет','год', ('года') x 3, ('лет') x 2 ]],
               };
 
-or for I<секунда> (shorthand equivalent is C<$epilog = 'sec.'> for C<'accusative'> case (Винительного падежа)):
+or for I<секунда> (shorthand equivalent is C<$epilog = 'sec'> for C<'accusative'> case (Винительного падежа)):
 
   my $epilog = {
                'object' => 'inanimate',
@@ -1553,7 +1552,7 @@ Currently available for:
 
 =item * zero (0) (I<ноль>, by default; C<< 'alt' => {0=>1} >>, to obtain I<нуль>).
 
-=item * C<'i.T'> key — Colloquial or Obsolete form for 'thousands' (I<тысяч>) in C<'instrumental'> cases (I<Творительный падеж>):
+=item * C<'i.T'> key — Colloquial or Obsolete form for 'thousands' (I<тысяч>) in C<'instrumental'> case (I<Творительный падеж>):
 
   say num2cardinal( 1000, case => 'i', alt => {'i.T'=>'Colloquial'} ); # or 'i.T'=>'C'
   say num2cardinal( 1000, case => 'i', alt => {'i.T'=>'Obsolete'} ); # or 'i.T'=>'O'
@@ -1565,7 +1564,7 @@ Will print the results:
   одной тысячею
   одной тысячей
 
-=item * C<'i.8'> key — сolloquial form for I<'восьмью'>, I<'восьмьюдесятью'>, I<'восьмьюстами'> in C<'instrumental'> cases (I<Творительный падеж>):
+=item * C<'i.8'> key — сolloquial form for I<'восьмью'>, I<'восьмьюдесятью'>, I<'восьмьюстами'> in C<'instrumental'> case (I<Творительный падеж>):
 
   say num2cardinal( $_, case => 'i', alt => {'i.8'=>'TRUE'} ) for 8000, 80, 800;
 
@@ -1581,7 +1580,7 @@ Instead traditional established forms:
   восемьюдесятью
   восемьюстами
 
-=item * C<'if1'> key — alternate form for I<'одною'> in C<'instrumental'> cases (I<Творительный падеж>) and C<'feminine'> gender:
+=item * C<'if1'> key — alternate form for I<'одною'> in C<'instrumental'> case (I<Творительный падеж>) and C<'feminine'> gender:
 
   say num2cardinal( 1000, case => 'i', gender => 'feminine', alt => {'if1'=>'TRUE'} );
   say num2cardinal( 1000, case => 'i', gender => 'feminine', alt => {'if1'=>'TRUE', 'i.T'=>'O'} ); # alternate and obsolete form
@@ -1605,8 +1604,7 @@ This subroutine is only intended to match C<'epilog'> case endings.
 It does NOT convert a C<$number> (natural numbers or 0) to Russian text (string, i.e. a numeral).
 Therefore, this subroutine makes sense when at least C<$number> and C<'epilog'> option are given.
 All global C<%facultative_options>, are the same as C<num2cardinal()> subroutine.
-In fact, this subroutine is a wrapper around the C<num2cardinal()> subroutine 
-with an additional parameter C<case_endings>:
+In fact, this subroutine is a wrapper around the C<num2cardinal()> subroutine:
 
   say case_endings( 1000, 'epilog'=>'RUB');
 
@@ -1645,7 +1643,7 @@ Lingua::RU::Numeral is known to run under perl 5.10.0 on Linux.
 
 =head1 CAVEATS
 
-The author of this module is not linguist. If you would like to help me correct numeral errors, please send me an email.
+The author of this module is not professional linguist. If you would like to help me correct numeral errors, please send me an email.
 
 =head1 SEE ALSO
 
@@ -1669,7 +1667,7 @@ Alessandro N. Gorohovski, E<lt>an.gorohovski@gmail.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2022-2023 by Alessandro N. Gorohovski
+Copyright (C) 2022-2025 by Alessandro N. Gorohovski
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.10.0 or,
